@@ -92,6 +92,22 @@ class Bitpin:
 
         return all_locals
 
+    def __make_url(self, url: str) -> str:
+        """
+        Make url.
+
+        :param url: Url
+        :type url: str
+
+        :return: Url
+        :rtype: str
+        """
+
+        if url.startswith('/'):
+            url = url[1:]
+
+        return f'{self.__base_url}/{url}'
+
     def __make_headers(self, func_name: str, auth: t.Optional[bool] = True) -> t.Dict:
         """
         Make headers.
@@ -224,7 +240,7 @@ class Bitpin:
         try:
             response = requests.request(
                 method,
-                self.__base_url + url,
+                self.__make_url(url),
                 headers=headers,
                 params=params,
                 json=json_data,
@@ -523,6 +539,27 @@ class Bitpin:
         return self._process_response(f_name, response, f_args)
 
     def create_order(self, market: int, order_type: str, side: str, amount: float, price: float = None) -> t.Dict:
+        """
+        Create order.
+
+        :param market: Market ID (required)
+        :type market: int
+
+        :param order_type: Order type (required)
+        :type order_type: str
+
+        :param side: Side (required)
+        :type side: str
+
+        :param amount: Amount (required)
+        :type amount: float
+
+        :param price: Price (optional)
+        :type price: float
+
+        :return: Order
+        :rtype: dict
+        """
 
         f_name = cf().f_code.co_name
         f_args = self.__get_func_args(locals())
@@ -552,6 +589,15 @@ class Bitpin:
         return self._process_response(f_name, response, f_args)
 
     def cancel_order(self, order_id: int) -> t.Dict:
+        """
+        Cancel order.
+
+        :param order_id: Order ID (required)
+        :type order_id: int
+
+        :return: Order
+        :rtype: dict
+        """
         
         f_name = cf().f_code.co_name
         f_args = self.__get_func_args(locals())
@@ -567,12 +613,18 @@ class Bitpin:
 
         return self._process_response(f_name, response, f_args)
     
-    def recent_trades(self):
-        
+    def order_history(self):
+        """
+        Get order history.
+
+        :return: Recent trades
+        :rtype: dict
+        """
+
         f_name = cf().f_code.co_name
         f_args = self.__get_func_args(locals())
 
-        url = 'v1/odr/orders/'
+        url = '/v1/odr/orders/'
 
         response = self._request(
             f_name,
@@ -581,4 +633,26 @@ class Bitpin:
             auth=True,
         )
 
-        return self._process_response(f_name, response, f_args)
\ No newline at end of file
+        return self._process_response(f_name, response, f_args)
+
+    def recent_trades(self):
+        """
+        Get recent trades.
+
+        :return: Recent trades
+        :rtype: dict
+        """
+
+        f_name = cf().f_code.co_name
+        f_args = self.__get_func_args(locals())
+
+        url = '/v1/odr/matches/'
+
+        response = self._request(
+            f_name,
+            'GET',
+            url,
+            auth=True,
+        )
+
+        return self._process_response(f_name, response, f_args)
